@@ -8,15 +8,8 @@
 // QSettings keys
 #define SETUP_XBMC_SERVER "xbmc/server"
 #define SETUP_XBMC_SERVER_DEFAULT "localhost"
-#define SETUP_XBMC_PORT "xbmc/port"
-#define SETUP_XBMC_PORT_DEFAULT "8080"
-
-#define SETUP_XBMC_REQUIRES_AUTHENTICATION "xbmc/requires_authetication"
-#define SETUP_XBMC_REQUIRES_AUTHENTICATION_DEFAULT false
-#define SETUP_XBMC_USERNAME "xbmc/username"
-#define SETUP_XBMC_USERNAME_DEFAULT ""
-#define SETUP_XBMC_PASSWORD "xbmc/password"
-#define SETUP_XBMC_PASSWORD_DEFAULT ""
+#define SETUP_XBMC_PORT "xbmc/evport"
+#define SETUP_XBMC_PORT_DEFAULT "9777"
 
 #define SETUP_SCREEN_DISABLE_SCREENSAVER "screen/disable_screensaver"
 #define SETUP_SCREEN_DISABLE_SCREENSAVER_DEFAULT false
